@@ -94,12 +94,14 @@ int snd_async_del_handler(snd_async_handler_t *handler)
 /* only for internal use */
 int _snd_set_nonblock(int fd, int nonblock);
 
+#if !SALSA_HAS_DUMMY_CONF
 /* the global function defined here */
 static inline
 int snd_config_update_free_global(void)
 {
 	return 0;
 }
+#endif /* !SALSA_HAS_DUMMY_CONF */
 
 /*
  * helper macros
