@@ -2,10 +2,13 @@
 #define __ALSA_RECIPE_H
 
 /* Build with TLV support */
-#define SALSA_HAS_TLV_SUPPORT	1
+#define SALSA_HAS_TLV_SUPPORT	0
 
 /* Build with async support */
-#define SALSA_HAS_ASYNC_SUPPORT	1
+#define SALSA_HAS_ASYNC_SUPPORT	0
+
+/* Build with dummy conf support */
+#define SALSA_HAS_DUMMY_CONF	0
 
 /* Enable deprecated attribute for non-working functions */
 #define SALSA_MARK_DEPRECATED	1
